Uses of Class
com.github.charithe.kafka.StartupMode
-
-
Uses of StartupMode in com.github.charithe.kafka
Methods in com.github.charithe.kafka that return StartupMode Modifier and Type Method Description StartupModestartupMode()static StartupModeStartupMode. valueOf(String name)Returns the enum constant of this type with the specified name.static StartupMode[]StartupMode. values()Returns an array containing the constants of this enum type, in the order they are declared.Constructors in com.github.charithe.kafka with parameters of type StartupMode Constructor Description KafkaJunitRule(EphemeralKafkaBroker broker, StartupMode mode)
-